@@ -1,4 +1,5 @@
 #define NPY_HAVE_ENDIAN_H 1
+#define NPY_HAVE_SYS_ENDIAN_H 1
 #define NPY_SIZEOF_SHORT SIZEOF_SHORT
 #define NPY_SIZEOF_INT SIZEOF_INT
 #define NPY_SIZEOF_LONG SIZEOF_LONG
@@ -6,9 +7,9 @@
 #define NPY_SIZEOF_COMPLEX_FLOAT 8
 #define NPY_SIZEOF_DOUBLE 8
 #define NPY_SIZEOF_COMPLEX_DOUBLE 16
-#define NPY_SIZEOF_LONGDOUBLE 12
-#define NPY_SIZEOF_COMPLEX_LONGDOUBLE 24
-#define NPY_SIZEOF_PY_INTPTR_T 4
+#define NPY_SIZEOF_LONGDOUBLE 16
+#define NPY_SIZEOF_COMPLEX_LONGDOUBLE 32
+#define NPY_SIZEOF_PY_INTPTR_T 8
 #define NPY_SIZEOF_OFF_T 8
 #define NPY_SIZEOF_PY_LONG_LONG 8
 #define NPY_SIZEOF_LONGLONG 8
@@ -21,11 +22,11 @@
 #define NPY_HAVE_COMPLEX_DOUBLE 1
 #define NPY_HAVE_COMPLEX_FLOAT 1
 #define NPY_HAVE_COMPLEX_LONG_DOUBLE 1
-#define NPY_ENABLE_SEPARATE_COMPILATION 1
+#define NPY_RELAXED_STRIDES_CHECKING 1
 #define NPY_USE_C99_FORMATS 1
 #define NPY_VISIBILITY_HIDDEN __attribute__((visibility("hidden")))
 #define NPY_ABI_VERSION 0x01000009
-#define NPY_API_VERSION 0x00000009
+#define NPY_API_VERSION 0x0000000C
 
 #ifndef __STDC_FORMAT_MACROS
 #define __STDC_FORMAT_MACROS 1
